@@ -7,7 +7,7 @@
 #' remoteServerAddr(localhost), port(4444), browserName(firefox), version(""), platform(ANY),
 #' javascript(TRUE). See examples for more information on use.
 #'
-#' @import RJSONIO
+#' @import rjson
 #' @import caTools
 #' @import methods
 #' @field remoteServerAddr Object of class \code{"character"}, giving the ip of the remote server. Defaults to localhost
@@ -590,9 +590,9 @@ remoteDriver <- setRefClass("remoteDriver",
                                 .self$value
                               },
                               
-                              addCookie = function(name,value,path,domain,secure = FALSE){
-                                "Set a cookie on the domain. The inputs are required apart from `secure` which defaults to FALSE."
-                                cookie<-list(name = name,value = value,path = path,domain = domain,secure = secure)
+                              addCookie = function(name,value,path = "/", domain = NULL, httpOnly = NULL, expiry = NULL,secure = FALSE){
+                                "Set a cookie on the domain. The inputs are required apart from those with default values."
+                                cookie<-list(name = name,value = value,path = path,domain = domain, httpOnly = httpOnly, expiry = expiry,secure = secure)
                                 queryRD(paste0(serverURL,'/session/',sessionInfo$id,'/cookie'),
                                         "POST",qdata=toJSON(list(cookie = cookie)))
                               },
